==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/layouts/activity-panel/ru.dictionary.itop.activity-panel.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('RU RU', 'Russian', 'Русский', [
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Активность',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Открыть панель активности',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Создать новую запись в журнале',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Закрыть',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Загрузить все записи',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Загрузить предыдущие записи',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'Нажав кнопку "Отправить", вы добавите записи во все редактируемые журнал одновременно.',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Одновременное обновление журналов',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Здесь пока пусто...',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Открыть дополнительную информацию по уведомлению',
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Расширить',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Уменьшить',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Активность',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Черновик',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Скрыть детализацию изменений',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Показать детализацию изменений',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Изменения',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Показать / скрыть изменения полей',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Choose which logs to display on this tab~~',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Журналы',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Показать / скрыть изменения журналов',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Статус',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Показать / скрыть изменение статуса',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Количество авторов выбранных категорий изменений',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Количество записей в выбранных журналах',
]);

==> iTop-3.2.1-1-16749.zip: web/dictionaries/ui/layouts/activity-panel/ru.dictionary.itop.activity-panel.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('RU RU', 'Russian', 'Русский', array(
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Расширить',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Уменьшить',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Закрыть',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Загрузить предыдущие записи',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Загрузить все записи',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Активность',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Черновик',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Журналы',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Показать / скрыть изменения журналов',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Choose which logs to display on this tab~~',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Статус',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Показать / скрыть изменение статуса',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Изменения',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Показать / скрыть изменения полей',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Показать детализацию изменений',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Скрыть детализацию изменений',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Количество авторов выбранных категорий изменений',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Количество записей в выбранных журналах',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Создать новую запись в журнале',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Одновременное обновление журналов',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'Нажав кнопку "Отправить", вы добавите записи во все редактируемые журнал одновременно.',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Открыть дополнительную информацию по уведомлению',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Здесь пока пусто...',
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Активность',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Открыть панель активности',
));
